#
# spec file for package mage
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mage
Version:        1.15.0
Release:        2.3
Summary:        A make-like build tool using Go
License:        Apache-2.0
URL:            https://github.com/magefile/mage
Source:         https://github.com/magefile/mage/archive/refs/tags/v%{version}.tar.gz
Patch0:         https://github.com/magefile/mage/pull/474.patch#/reproducible.patch
BuildRequires:  go
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.12

%description

Mage is a make-like build tool using Go. You write plain-old go functions, and Mage automatically uses them as Makefile-like runnable targets.

%prep
%autosetup -p1

%build
if test -z "$GOPATH"; then
	GOPATH="$HOME/go"
fi
mkdir -p $GOPATH
go run bootstrap.go

%install
mkdir -p %{buildroot}%{_bindir}
if test -z "$GOPATH"; then
	GOPATH="$HOME/go"
fi
mv $GOPATH/bin/mage %{buildroot}%{_bindir}

%files
%license LICENSE
%doc README.md
%{_bindir}/mage

%changelog
* Sat Feb 15 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.15.0:
  * Update CI (#466)
  * fix erroneous docstring of sh.Exec() (#452)
  * Update jQuery to 3.5.0 (#458)
  * -d dir contains magefiles stop with "No .go files marked with the
    mage build tag..." (#447) (#448)
  * mage: cancel context on SIGINT (#313)
  * give props to netlify on the main page
  * Update site to build with newer hugo
  * bring docs for use of directives up to date
  * add blog post about v1.13
  * fix author links
  * Add variadic support to mg.F
  * feat: rename templated imports to avoid collisions
  * Website: fixing typos
  * refactor(listGoFiles): remove go list dependency
  * doc: add MacPorts install info
  * feat: allow mage:import alias to be defined for multiple imports
  * Detect deps that have already been invoked
  * Replace godoc.org URLs
  * Add magefiles directory support
  * ci: migrate from travis to github action (#391)
  * evidently goreleaseer has changed in the last 4 years :) (#394)
  * Fix the rollback mechanism for tags during a release (#392)
  * sh.run(): quoted strings before join (#306)
  * Add asdf installation instructions to docs (#383)
  * #288 add brew and scoop install to docs (#376)
  * #378 bump travisci go16 (#379)
  * Create issue templates (#374)
  * fix: deterministic compiled mainfile (#348)
  * make -h work with imported targets (#335)
  * fix test for go 1.16 (#330)
* Fri Jan  7 2022 Jeff Mahoney <jeffm@suse.com>
- Reduce go dependency to >= 1.12 as that's all mage requires.
* Wed Dec 15 2021 Jeff Mahoney <jeffm@suse.com>
- Initial packaging.
